@@ -70,7 +70,7 @@ spin_output_with_default_string (GtkSpinButton *spin,
 	return TRUE;
 }
 
-gboolean
+static gboolean
 ce_spin_output_with_automatic (GtkSpinButton *spin, gpointer user_data)
 {
 	return spin_output_with_default_string (spin,
@@ -78,7 +78,7 @@ ce_spin_output_with_automatic (GtkSpinButton *spin, gpointer user_data)
 	                                        _("automatic"));
 }
 
-gboolean
+static gboolean
 ce_spin_output_with_default (GtkSpinButton *spin, gpointer user_data)
 {
 	return spin_output_with_default_string (spin,
@@ -86,6 +86,63 @@ ce_spin_output_with_default (GtkSpinButton *spin, gpointer user_data)
 	                                        _("default"));
 }
 
+static gint
+spin_input_with_default_string (GtkSpinButton *spin,
+                                int defvalue,
+                                gdouble *new_val,
+                                const char *defstring)
+{
+	const gchar *buf;
+
+	buf = gtk_entry_get_text (GTK_ENTRY (spin));
+	if (strcmp (buf, defstring) == 0) {
+		*new_val = defvalue;
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static gint
+ce_spin_input_with_automatic (GtkSpinButton *spin, gdouble *new_val, gpointer user_data)
+{
+	return spin_input_with_default_string (spin,
+	                                       GPOINTER_TO_INT (user_data),
+	                                       new_val,
+	                                       _("automatic"));
+}
+
+static gint
+ce_spin_input_with_default (GtkSpinButton *spin, gdouble *new_val, gpointer user_data)
+{
+	return spin_input_with_default_string (spin,
+	                                       GPOINTER_TO_INT (user_data),
+	                                       new_val,
+	                                       _("default"));
+}
+
+void
+ce_spin_automatic_val (GtkSpinButton *spin, int defvalue)
+{
+	g_signal_connect (spin, "output",
+	                  G_CALLBACK (ce_spin_output_with_automatic),
+	                  GINT_TO_POINTER (defvalue));
+	g_signal_connect (spin, "input",
+	                  G_CALLBACK (ce_spin_input_with_automatic),
+	                  GINT_TO_POINTER (defvalue));
+}
+
+void
+ce_spin_default_val (GtkSpinButton *spin, int defvalue)
+{
+	g_signal_connect (spin, "output",
+	                  G_CALLBACK (ce_spin_output_with_default),
+	                  GINT_TO_POINTER (defvalue));
+	g_signal_connect (spin, "input",
+	                  G_CALLBACK (ce_spin_input_with_default),
+	                  GINT_TO_POINTER (defvalue));
+}
+
 int
 ce_get_property_default (NMSetting *setting, const char *property_name)
 {
@@ -509,7 +566,9 @@ ce_page_get_next_available_name (const GPtrArray *connections, const char *forma
 		char *temp;
 		gboolean found = FALSE;
 
+		NM_PRAGMA_WARNING_DISABLE("-Wformat-nonliteral")
 		temp = g_strdup_printf (format, i);
+		NM_PRAGMA_WARNING_REENABLE
 		for (iter = names; iter; iter = g_slist_next (iter)) {
 			if (!strcmp (iter->data, temp)) {
 				found = TRUE;
