@@ -108,9 +108,7 @@ populate_ui (CEPageInfiniband *self)
 
 	/* MTU */
 	mtu_def = ce_get_property_default (NM_SETTING (setting), NM_SETTING_INFINIBAND_MTU);
-	g_signal_connect (priv->mtu, "output",
-	                  G_CALLBACK (ce_spin_output_with_automatic),
-	                  GINT_TO_POINTER (mtu_def));
+	ce_spin_automatic_val (priv->mtu, mtu_def);
 
 	gtk_spin_button_set_value (priv->mtu, (gdouble) nm_setting_infiniband_get_mtu (setting));
 }
@@ -242,6 +240,7 @@ ce_page_infiniband_class_init (CEPageInfinibandClass *infiniband_class)
 void
 infiniband_connection_new (GtkWindow *parent,
                            const char *detail,
+                           gpointer detail_data,
                            NMClient *client,
                            PageNewConnectionResultFunc result_func,
                            gpointer user_data)
