@@ -33,7 +33,7 @@ vpn_get_plugin_by_service (const char *service)
 {
 	NMVpnPluginInfo *plugin_info;
 
-	plugin_info = nm_vpn_plugin_info_list_find_by_service (vpn_get_plugins (), service);
+	plugin_info = nm_vpn_plugin_info_list_find_by_service (vpn_get_plugin_infos (), service);
 	if (plugin_info)
 		return nm_vpn_plugin_info_get_editor_plugin (plugin_info);
 	return NULL;
@@ -46,7 +46,7 @@ _sort_vpn_plugins (NMVpnPluginInfo *aa, NMVpnPluginInfo *bb)
 }
 
 GSList *
-vpn_get_plugins ()
+vpn_get_plugin_infos (void)
 {
 	static gboolean plugins_loaded = FALSE;
 	static GSList *plugins = NULL;
@@ -64,9 +64,12 @@ vpn_get_plugins ()
 
 		/* load the editor plugin, and preserve only those NMVpnPluginInfo that can
 		 * successfully load the plugin. */
-		if (nm_vpn_plugin_info_load_editor_plugin (plugin_info, &error))
+		if (nm_vpn_plugin_info_load_editor_plugin (plugin_info, &error)) {
 			plugins = g_slist_prepend (plugins, plugin_info);
-		else {
+			g_info ("vpn: (%s,%s) loaded",
+			        nm_vpn_plugin_info_get_name (plugin_info),
+			        nm_vpn_plugin_info_get_filename (plugin_info));
+		} else {
 			if (   !nm_vpn_plugin_info_get_plugin (plugin_info)
 			    && nm_vpn_plugin_info_lookup_property (plugin_info, NM_VPN_PLUGIN_INFO_KF_GROUP_GNOME, "properties")) {
 				g_message ("vpn: (%s,%s) cannot load legacy-only plugin",
@@ -117,7 +120,7 @@ import_vpn_from_file_cb (GtkWidget *dialog, gint response, gpointer user_data)
 		goto out;
 	}
 
-	for (iter = vpn_get_plugins (); !connection && iter; iter = iter->next) {
+	for (iter = vpn_get_plugin_infos (); !connection && iter; iter = iter->next) {
 		NMVpnEditorPlugin *plugin;
 
 		plugin = nm_vpn_plugin_info_get_editor_plugin (iter->data);
@@ -329,8 +332,10 @@ vpn_supports_ipv6 (NMConnection *connection)
 	g_return_val_if_fail (service_type != NULL, FALSE);
 
 	plugin = vpn_get_plugin_by_service (service_type);
-	g_return_val_if_fail (plugin != NULL, FALSE);
+	if (!plugin)
+		return FALSE;
 
 	capabilities = nm_vpn_editor_plugin_get_capabilities (plugin);
 	return (capabilities & NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6) != 0;
 }
+
