@@ -94,5 +94,8 @@ void utils_set_cell_background (GtkCellRenderer *cell,
 
 void utils_fake_return_key (GdkEventKey *event);
 
+void widget_set_error   (GtkWidget *widget);
+void widget_unset_error (GtkWidget *widget);
+
 #endif /* UTILS_H */
 
